######################## QTL ANALYSIS ##########################
#####
##### Written by Frederic Bouche. Contact: f.bouche@wisc.edu
#####
##### FILE ORGANIZATION : 1 - PARAMETERS USED IN THE ANALYSIS
#####                     2 - PACKAGE/FILE LOADING AND FOLDER CREATION
#####                     3 - RESHAPE PHENO DATA
#####                     4 - RESHAPE GENO DATA AND GENETIC MAP
#####                     5 - FILTER DATA
#####                     6 - SINGLE PEAK QTL ANALYSIS
#####                     7 - TWO-PEAKS QTL ANALYSIS
#####

# Before running the script, indicate the location of the folder
# containing the "QTL_analysis.R" file. This folder should also
# contain the "DATA" folder, which itself includes raw data.

path <- "/Users/johndoe/Desktop/Supplemental_dataset_woods_2016" #e.g. "/Users/username/Desktop/Supplemental_dataset_woods_2016"

setwd(path)

#@###--------------- 1 - PARAMETERS USED IN THE ANALYSIS--------#######
### We begin by setting the different parameters of the analysis
## Set the number of days for plants that did not flower
value_max_FT_days <- 120
## Set the number of leaves at flowering for plants that did not flower
value_max_FT_leaves <- 20
## Set proportion of present data under which the marker will be removed
marker_missing_data_threshold <- 0.85 # Proportion [0 to 1]
## Set the max proportion of missing data for a genotype, above which
## the RIL is removed
individual_missing_data_threshold <- 0.3 # Proportion [0 to 1]
## Set the max proportion of a specific genotype, above which
## the RIL is removed
up_threshold_per_genotype <- 0.9 # Proportion [0 to 1]
## Set the minimal proportion of a specific genotype, under which
## the RIL is removed
down_threshold_per_genotype <- 0.1 # Proportion [0 to 1]
## Set the maximal proportion of identity between two lines, above 
## which one the two line is removed. 
threshold_identic_lines <- 0.9 # Proportion [0 to 1]
## Do you want to infer missing data from the closest markers (uses a simple inferance method) 
Fill_missing <- "NO" # Either "YES" or "NO" (UPPERCASE)
## Which method should be employed for QTL computing ?
scaneone_method <- "hk" # May be set to: "em","imp","hk", "ehk", "mr". (lowercase)
## Set the number of permutations and the alpha threshold for the single peak method calculation?
number_permutations <- 10000
alpha_permutation <- 0.05
# DO WE WANT TO USE
Perform_scantwo_permutation <- "NO" # Might be either YES or NO (UPPERCASE)
## Set the number of permutation and the alpha threshold for the single peak method calculation?
number_permutations_two <- 1000
alpha_permutation_two <- 0.05
## The permutation  might take a lot of time. Hence, we can skip or spread it over several cores:
## If your computer allows it, on how many core do you want to perform the permutation (Takes hours)
number_of_clusters <- 1 # 1 by default

#@#####--------------- 2 - PACKAGES/FILES LOADING AND FOLDER CREATION --------#####
# Function to check for existing packages and download them.
install.packages.auto <- function(x) { 
  x <- as.character(substitute(x)) 
  if(isTRUE(x %in% .packages(all.available=TRUE))) { 
    eval(parse(text = sprintf("require(\"%s\")", x)))
  } else { 
    #update.packages(ask= FALSE) #update installed packages.
    eval(parse(text = sprintf("install.packages(\"%s\", dependencies = TRUE)", x)))
  }
  if(isTRUE(x %in% .packages(all.available=TRUE))) { 
    eval(parse(text = sprintf("require(\"%s\")", x)))
  } else {
    source("http://bioconductor.org/biocLite.R")
    #biocLite(character(), ask=FALSE) #update installed packages.
    eval(parse(text = sprintf("biocLite(\"%s\")", x)))
    eval(parse(text = sprintf("require(\"%s\")", x)))
  }
 }
# Load/install the packages
install.packages.auto(qtl)
install.packages.auto(qtl)
install.packages.auto(ggplot2)
install.packages.auto(ggthemes)
install.packages.auto(data.table)
install.packages.auto(dplyr)
install.packages.auto(snow)

# Now, we create the folder that will be used to store outputs
dir.create("Figure_results",showWarnings = F)
dir.create("Tables_produced",showWarnings = F)
path_to_results <- paste(path,"Figure_results",sep='/')
path_to_tables <- paste(path,"Tables_produced",sep='/')

# Finally, we load the raw data that should be in the "data folder" within
# the path in which the "QTL_analysis.R" file. Here is the list of files
Name_raw_data_file_geno <- "1_Genotype_Data_VF.csv"
Name_raw_data_file_pheno <- "2_Phenotypes.csv" 
Name_raw_data_genetic_map <- "3_Table_genetic_and_physical_map.csv"

# We create the corresponding paths
path.1.genotypes <- paste(path,"/Data/",Name_raw_data_file_geno, sep="")
path.2.phenotypes <- paste(path,"/Data/",Name_raw_data_file_pheno, sep="")
path.3.genetic.map <- paste(path,"/Data/",Name_raw_data_genetic_map, sep="")

# And load the csv files
raw.data.geno <- read.csv(path.1.genotypes, header=T)
raw.data.pheno <- read.csv(path.2.phenotypes, header=F,stringsAsFactors=FALSE)
genetic.map.raw <- read.csv(path.3.genetic.map, header=F,stringsAsFactors=FALSE, sep="\t")
#####

#@#####--------------- 3 - DATA CURATION/RESHAPING PHENOTYPIC DATA --------#####
# We set the raw phenotypic data as a new table
datapheno.reshaped <- raw.data.pheno
# We perform several manipulation to reshape the table for our needs
datapheno.reshaped <- datapheno.reshaped[-c(1),]
row.names(datapheno.reshaped) <- datapheno.reshaped[,1]
datapheno.reshaped <- datapheno.reshaped[,-1]
colnames(datapheno.reshaped) <- paste(datapheno.reshaped[1,],datapheno.reshaped[2,],(datapheno.reshaped[3,]),sep="_")
datapheno.reshaped <- datapheno.reshaped[-c(1:3),]
# The data table is gathered in a shape required for GGPLOT2 drawing
datapheno.ggplot2 <-  tidyr::gather(datapheno.reshaped,"Condition","Value",1:length(datapheno.reshaped))
# The different variables stored in one column are splitted
datapheno.ggplot2$Growth_Condition <- gsub("_.*","",datapheno.ggplot2$Condition)
datapheno.ggplot2$Organ <- gsub(".*_(.*)_.*", "\\1", datapheno.ggplot2$Condition)
datapheno.ggplot2$Type_of_variable <- gsub(".*_","",datapheno.ggplot2$Condition)
datapheno.ggplot2$Condition <- NULL
# We save this table as an output
write.csv(datapheno.ggplot2,paste(path_to_tables,"/1b_Table_flowering_ggplot2.csv",sep=""))

#Now, we will modify the table to fit the input needed for R\qtl
# As the SD is not used by R\qtl to compute results, it is removed from the table
datapheno.reshaped.2 <- datapheno.reshaped[,-grep("SD",colnames(datapheno.reshaped))]
# As the genotype data have more rows, we add 2 empty raws to the begining of the table
empty_frame <- c(rep("",length(datapheno.reshaped.2[1,])))
empty_frame <- t(data.frame(Region= empty_frame, Chromosom=empty_frame))
colnames(empty_frame) <- colnames(datapheno.reshaped.2)
datapheno.reshaped.2 <- rbind(empty_frame,datapheno.reshaped.2)
datapheno.reshaped.2$ID <- row.names(datapheno.reshaped.2)
write.csv(datapheno.reshaped.2,paste(path_to_tables,"/1a_Table_flowering_reshaped_for_rqtl.csv",sep=""))

#@###--------------- 4 - RESHAPE GENO DATA AND GENETIC MAP --------#######

### A - RESHAPE GENOTYPIC DATA
geno.data.to.clean <- raw.data.geno
# We remove the duplicated lines
geno.data.to.clean<-geno.data.to.clean[-which(duplicated(geno.data.to.clean$ID)),]
# We remove the lines that are not present in the phentype table
values <- c(setdiff(geno.data.to.clean$ID,datapheno.reshaped.2$ID))
for(i in 1:length(values)){
  row_identified <- which(geno.data.to.clean$ID==values[i])
  geno.data.to.clean <- geno.data.to.clean[-row_identified,]
}
# We set the IDs as row names
geno.data.cleaned <- geno.data.to.clean
row.names(geno.data.cleaned) <- geno.data.cleaned$ID
geno.data.cleaned$ID<- NULL
datapheno.reshaped.2$ID <- NULL

# We rename the markers (BdX.XXXXX -> BdX_XXXXX)
marker_name <- colnames(geno.data.cleaned)
marker_name <-  gsub("\\.", "_", marker_name)
colnames(geno.data.cleaned) <- marker_name

#### B - Reshape data from the genetic map
# We need now the data from the computed genetic map
# We use the genetic map data
genetic_map <- genetic.map.raw
# The physical region is extracted from the name of the marker, which consist of Bd1=chromosome, followed by "_", and the position of the marker on the chromosome, but we convert it into Mb
region <- as.numeric(gsub(".*_", "", marker_name))/1000000
# We then extract the chromosom number
chromosom <- gsub("_.*", "", marker_name)
chromosom2 <-  as.numeric(gsub("Bd", "", chromosom))

# Then, we create a table to with these information
table_regions_chromosom <- data.frame(Chromosom=chromosom2,Region= region)
row.names(table_regions_chromosom) <- marker_name
table_regions_chromosom <- t(table_regions_chromosom)

# this table is fused to the table with markers
Final_markers_table.2 <- rbind(table_regions_chromosom, geno.data.cleaned)

# The final step is to merge both datasets
## First we create a new ID column from the the row.names
Final_markers_table.2$ID <- row.names(Final_markers_table.2)
datapheno.reshaped.2$ID <- row.names(datapheno.reshaped.2)
## And we merge them
final_table <- cbind.data.frame(datapheno.reshaped.2,Final_markers_table.2)
## We remove the last col
final_table <- final_table[,-c(length(final_table[1,]))]
final_table.2 <- final_table
row.names(final_table.2) <- NULL
# To match the data structure needed for rqtl, we will remove the ID value for "chromosoms" and "region"
id_name <- gsub("Chromosom", "", final_table.2$ID)
id_name <- gsub("Region", "", id_name)
final_table.2$ID <- id_name 
# We remove the ID column, as it is not displayed in the analyis
#final_table.2$ID <- NULL 
# We have to save this information as a CSV that will be opened by the R\qtl package + we can verify these info
path_to_reshaped_markers <- paste(path,"Tables_produced/2_Reshaped_markers_with_physcial_and_genetic_distances.csv", sep="/")
write.table(final_table.2,path_to_reshaped_markers, sep="\t", quote=F, row.names=F)
#####



#@###--------------- 5 - FILTER DATA (MARKER SELECTION - RIL FILTERING) --------#######
# We load the data using the read.cross function from the R\qtl package
qtl_all_data <- read.cross("csv",path_to_tables,"/2_Reshaped_markers_with_physcial_and_genetic_distances.csv", genotypes=c("Bd11", "Bd21"), sep="\t", dec=",", crosstype="riself")
print(summary(qtl_all_data))

##### 3A - Analysis of missing data ###
#First, we draw a graph to visualize the missing data
png(paste(path_to_results,'/1_Missing_data_before_filtering.png', sep=""))
plotMissing(qtl_all_data, main="Missing data before filtering")
dev.off()
# Then, we determine the bad markers, in which we have a lot of missing data
nt.bymar <- ntyped(qtl_all_data, "mar")
number_of_lines <- max(nt.bymar)
nt.bymar.value <- (nt.bymar)/(number_of_lines)
todrop <- names(nt.bymar.value[nt.bymar.value < marker_missing_data_threshold])
qtl_all_data <- drop.markers(qtl_all_data, todrop)

# We determine which individuals had >30% missing data
value_missing <- nmissing(qtl_all_data)
value_present <- ntyped(qtl_all_data)
proportion_missing <- value_missing/(value_present+value_missing)
# We print them and we remove them from the data and save it in a table
print("line with > 30 % of missing data")
print(proportion_missing[proportion_missing>individual_missing_data_threshold])
all_removed_lines <-proportion_missing[proportion_missing>individual_missing_data_threshold]
line_removed <- names(all_removed_lines)
proportion_missing_data <- all_removed_lines
removed_data_table <- data.frame(line=line_removed,missing_data=proportion_missing_data)
path_to_missing_data_save <- paste(path,"/Tables_produced/3_Removed_lines_because_missing_data.csv", sep="")
write.table(removed_data_table,path_to_missing_data_save, sep="\t", quote=F, row.names=F)

qtl_all_data <- qtl_all_data[,proportion_missing<=individual_missing_data_threshold]
# we plot this value and 
png(paste(path_to_results,'/2_Missing_data_after_filtering.png', sep=""))
plotMissing(qtl_all_data, main="Missing data after filtering")
dev.off()

###### 3B - Others filters - percentage each genotype ##

### First, we will check the proportion of each marker across the different lines
png(paste(path_to_results,'/4A_genotypic_data_before_filtering.png', sep=""))
geno.image(qtl_all_data, chr=c(1:5), main="Genotype before filtering", sub="AA=Bd11=red ; AB=blue ; BB=Bd21=green")
dev.off()
# Now, we calculatee the proportion of AA data
pA.qtl_all_data <- rowMeans(pull.geno(qtl_all_data) == 1, na.rm=TRUE)
names(pA.qtl_all_data) <- qtl_all_data$pheno$ID
pA.qtl_all_data[pA.qtl_all_data > up_threshold_per_genotype | pA.qtl_all_data < down_threshold_per_genotype]

# Now, we calculare the proportion of BB data
pB.qtl_all_data <- rowMeans(pull.geno(qtl_all_data) == 2, na.rm=TRUE)
names(pB.qtl_all_data) <- qtl_all_data$pheno$ID
pB.qtl_all_data[pB.qtl_all_data > up_threshold_per_genotype | pB.qtl_all_data < down_threshold_per_genotype]

png(paste(path_to_results,'/3_proportion_of_each_genotype.png', sep=""))
par(mfrow=c(1,2), las=1)
plot(pA.qtl_all_data, ylim=c(0,1), ylab="Proportion of (AA)", main="Proportion of AA (Bd1-1)")
plot(pB.qtl_all_data, ylim=c(0,1), ylab="Proportion of (BB)", main="Proportion of BB (Bd21)")
dev.off()
# We drop the lines that are too similar
qtl_all_data <- qtl_all_data[,pA.qtl_all_data > down_threshold_per_genotype & pA.qtl_all_data < up_threshold_per_genotype]
qtl_all_data <- qtl_all_data[,pB.qtl_all_data > down_threshold_per_genotype & pB.qtl_all_data < up_threshold_per_genotype]
# Now, we will draw images of each chromosomes to see wether some regions appear to be enriched specifically in one genotype
png(paste(path_to_results,'/4B_genotypic_data_after_filtering.png', sep=""))
par(mfrow=c(1,1), las=1)
geno.image(qtl_all_data, chr=c(1:5), main="Genotype data after filtering",sub="AA=Bd11=red ; AB=blue ; BB=Bd21=green")
dev.off()

# Which lines were removed. 
qtl_all_data_missing <- qtl_all_data
qtl_all_data_missing.2 <- qtl_all_data
if(length(which(pA.qtl_all_data < down_threshold_per_genotype & pA.qtl_all_data > up_threshold_per_genotype))>0){
  qtl_all_data_missing <- qtl_all_data[,pA.qtl_all_data < down_threshold_per_genotype & pA.qtl_all_data > up_threshold_per_genotype]
  qtl_all_data_missing.2 <- qtl_all_data[,pA.qtl_all_data > down_threshold_per_genotype & pA.qtl_all_data < up_threshold_per_genotype]
}


if(length(which(pB.qtl_all_data < down_threshold_per_genotype & pB.qtl_all_data > up_threshold_per_genotype))>0){
  qtl_all_data_missing <- qtl_all_data_missing[,pB.qtl_all_data < down_threshold_per_genotype & pB.qtl_all_data > up_threshold_per_genotype]
  qtl_all_data_missing.2 <- qtl_all_data_missing.2[,pB.qtl_all_data > down_threshold_per_genotype & pB.qtl_all_data < up_threshold_per_genotype]
}

removed_data_Markers <- as.data.frame(qtl_all_data_missing$pheno$ID)
path_to_missing_data_pheno <- paste(path,"/Tables_produced/4_Removed_lines_because_abnormal_genotypic_data-if-none-all-lines_shown.csv", sep="")
write.table(removed_data_Markers,path_to_missing_data_pheno, sep="\t", quote=F, row.names=F)
qtl_all_data <- qtl_all_data_missing.2

###### 3C - Others filters - Simlar lines ###
# We will create a function to retrieve the information about identical line in the analysis. Note that this function was created by Karl Broman (the author of the R qtl package)
near_matches <-
  function(cross, line_name="line", thresh=0.8)
  {
    cg <- comparegeno(cross)
    wh <- which(!is.na(cg) & cg > thresh & row(cg) < col(cg), arr=TRUE)
    if(length(wh)==0) return(NULL)
    
    if(is.null(line_name))
      id <- 1:nrow(cg)
    else
      id <- cross$pheno[,line_name]
    
    g <- pull.geno(cross)
    
    match <- not_mis <- rep(0, nrow(wh))
    for(i in 1:nrow(wh)) {
      match[i] <- sum(g[wh[i,1],] == g[wh[i,2],], na.rm=TRUE)
      not_mis[i] <- sum(!is.na(g[wh[i,1],]) & !is.na(g[wh[i,2],]))
    }
    
    result <- data.frame(line1=id[wh[,1]],
                         line2=id[wh[,2]],
                         percent_match=match/not_mis*100,
                         match=match,
                         total=not_mis)
    
    # sort by decreasing percent matching
    result <- result[order(result$percent_match, decreasing=TRUE),,drop=FALSE]
    rownames(result) <- 1:nrow(result)
    
    result
  }

# We will identify the near-matching genotypes to see if we have identical lines
cg.qtl_all_data <- comparegeno(qtl_all_data)
png(paste(path_to_results,'/5_near_matching_lines.png', sep=""))
hist(cg.qtl_all_data[lower.tri(cg.qtl_all_data)], breaks=seq(0, 1, len=251),
     xlab="Proportion matching", main="Analysis of near matching lines")
rug(cg.qtl_all_data[lower.tri(cg.qtl_all_data)])
dev.off()
print(near_matches(qtl_all_data, "ID"), digits=3)
near_matches_table <- near_matches(qtl_all_data, "ID")
path_to_near_matches_table <- paste(path,"/Tables_produced/5_Near_matching_lines-over90perc_are_removed.csv", sep="")
write.table(near_matches_table,path_to_near_matches_table, sep="\t", quote=F, row.names=F)

# We find the line corresponding to these duplication and we remove them from the dataset. the second line is removed.
cg <- comparegeno(qtl_all_data)
wh <- which(cg > threshold_identic_lines, arr=TRUE)
wh <- wh[wh[,1] < wh[,2],]
wh <- as.data.frame(wh)
qtl_all_data <- subset(qtl_all_data, ind=-wh[2,])

##### BEWARE TO CHECK THIS STEP DURING ANALYSIS
# Now, we will plot the genetic map of the conserved markers
png(paste(path_to_results,'/6_Physical_map_of_conserved_markers.png', sep=""))
plotMap(qtl_all_data, main="Physical map")
dev.off()
summary_physical_map <- summary.map(qtl_all_data)
##### 3D - Verification of the phenotypes
# We will now chceck that the phenotypes are interpreted in the right way
png(paste(path_to_results,'/7_Verification_of_phenotypic_observations.png', sep=""), width = 700, height = 900)
par(mfrow=c(4,3), las=1)
plotPheno(qtl_all_data, pheno.col=1)
plotPheno(qtl_all_data, pheno.col=2)
plotPheno(qtl_all_data, pheno.col=3)
plotPheno(qtl_all_data, pheno.col=4)
plotPheno(qtl_all_data, pheno.col=5)
plotPheno(qtl_all_data, pheno.col=6)
plotPheno(qtl_all_data, pheno.col=7)
plotPheno(qtl_all_data, pheno.col=8)
plotPheno(qtl_all_data, pheno.col=9)
plotPheno(qtl_all_data, pheno.col=10)
dev.off()
write.cross(qtl_all_data, format='csv', paste(path,"/Tables_produced/6_Data_with_selected_markers", sep=""))
print(summary(qtl_all_data))





#### 4 - Addition of the genetic map data ######
genetic_map_table <- genetic.map.raw 
colnames(genetic_map_table) <- genetic_map_table[1,]
genetic_map_table <- genetic_map_table[-1,]
marker_table <- Final_markers_table.2

# We create a list of the seletected markers
Selected_markers <- paste(genetic_map_table$Marker)

# We reorder the table of markers using our first table (this line of code uses the order of markers from the genetic map to order the columns in the original table)
marker_table_filtered <- marker_table[,match(Selected_markers, colnames(marker_table))] 

# We extract the genetic position from the original table
genetic_position <- genetic_map_table$GeneticPosition
# We replace the physical values by the region in CM
marker_table_filtered[2,] <- genetic_position
marker_table_filtered$ID <- row.names(Final_markers_table.2)

## And we merge them
final_table.3 <- cbind.data.frame(datapheno.reshaped.2,marker_table_filtered)
## We remove the last col
final_table.3 <- final_table.3[,-c(length(final_table.3[1,]))]
row.names(final_table.3) <- NULL
# To match the data structure needed for rqtl, we will remove the ID value for "chromosoms" and "region"
id_name <- gsub("Chromosom", "", final_table.3$ID)
id_name <- gsub("Region", "", id_name)
final_table.3$ID <- id_name 

# We will now filter 
lines_kept_temp <- qtl_all_data$pheno 
lines_kept <- lines_kept_temp$ID

value_to_remove <- setdiff(final_table.3$ID,lines_kept)
value_to_remove <- na.omit(as.integer(value_to_remove))
value_to_remove <- as.integer(value_to_remove)
# We have to save this information as a CSV that will be opened by the R\qtl package + we can verify these info
final_table.4 <- final_table.3[-c(which(final_table.3$ID %in% value_to_remove)), ]
# We save this table as a csv file
write.table(final_table.4,paste(path,"/Tables_produced/7_qtl_reshaped_table_2_GENETIC_distances_all_markers.csv", sep=""), sep="\t", quote=F, row.names=F)
#######


#@###--------------- 6 - SINGLE PEAK MODEL - QTL ANALYSIS --------#######

##### A - COMPUTATION
# We read the data
qtl_all_data <- read.cross("csv",path,"/Tables_produced/7_qtl_reshaped_table_2_GENETIC_distances_all_markers.csv", genotypes=c("Bd11", "Bd21"), sep="\t", dec=",",crosstype="riself")
print(summary(qtl_all_data))

# Before doing the QTL analysis, and if decided at the beginning of the script, we will fill the missing value remaining using the fill.geno function
if(Fill_missing==T){qtl_all_data <- fill.geno(qtl_all_data)}else{qtl_all_data <- qtl_all_data}
if(Fill_missing==T){
  png(paste(path_to_results,'/7bis_data_if_filled.png', sep=""), width = 700, height = 900)
  geno.image(qtl_all_data)
  dev.off()
}

png(paste(path_to_results,'/6b_Genetic_map_of_conserved_markers.png', sep=""))
plotMap(qtl_all_data, main="Genetic map")
dev.off()
summary_genetic_map <- summary.map(qtl_all_data) 
sum(summary_genetic_map$length)

qtl_all2 <- qtl_all_data
# Now, we calculate the probability for each position according to the phenotypes
qtl_all2 <- calc.genoprob(qtl_all2, step=1, stepwidth="fixed", err=0.001)
# We calculate the marker value for each pair of phenotype
out.qtl.1 <- scanone(qtl_all2, method=scaneone_method, phe=1:2)
out.qtl.2 <- scanone(qtl_all2, method=scaneone_method, phe=3:4)
out.qtl.3 <- scanone(qtl_all2, method=scaneone_method, phe=5:6)
out.qtl.4 <- scanone(qtl_all2, method=scaneone_method, phe=7:8)
out.qtl.5 <- scanone(qtl_all2, method=scaneone_method, phe=9:10)
# We also create a new table that will be employed to draw the final graphs. Note that we removed the segragating lines. 
out.qtl.all.results <- scanone(qtl_all2, method=scaneone_method, phe=c(1:10))

# Then, we use the built in function to scane each pair of phenotype (leaf and days for each condition on the same graph) the different results from the analysis
png(paste(path_to_results,'/8_Raw_graphs_QTL.png', sep=""), width = 600, height = 900)
par(mfrow=c(5,1), las=1)
# NV_h16
plot(out.qtl.1, lod=1:2, ylim=c(0,10), ylab="LOD score",main="NV - h16")
# NV_20h
plot(out.qtl.2, lod=1:2, ylim=c(0,10), ylab="LOD score",main="NV - 20h")
# 2W V 16h
plot(out.qtl.3, lod=1:2, ylim=c(0,10), ylab="LOD score",main="2 weeks of vernalization - 16h")
# 2W V 20h
plot(out.qtl.4, lod=1:2, ylim=c(0,10), ylab="LOD score",main="2 weeks of vernalization - 20h")
# 3W V 16h - Segragating
plot(out.qtl.5, lod=1:2, ylim=c(0,10), ylab="LOD score",main="3 weeks of vernalization - 16h")
dev.off()

##### B - CALCULATION OF THE SIGNIFICANCE
# We perform the permutations
operm <- scanone(qtl_all2, method=scaneone_method,  n.perm=number_permutations,n.cluster=number_of_clusters)
# We isolate the value of the LOD treshold
summary(operm, alpha=alpha_permutation)
lod_value <- summary(operm, alpha=alpha_permutation)
LOD_value_auto <- lod_value[1]

###### C - GGPLOT2 graphs
# We extract the value of the results and create a new object
out.qtl.all<- out.qtl.all.results
names_phenotypes <- colnames(out.qtl.all)
names_phenotypes <- gsub("\\.", "_", names_phenotypes)
names_phenotypes <- gsub("X", "", names_phenotypes)
colnames(out.qtl.all) <- names_phenotypes
out.qtl.all$Marker_name <- row.names(out.qtl.all)
out.qtl.all <- as.data.frame(out.qtl.all)
col_idx <- grep("Marker", names(out.qtl.all))
out.qtl.all <- subset(out.qtl.all, select=c(1:2,col_idx,3:(length(out.qtl.all)-1)))

# We extract the flowering data with only the days as flowering scoring
out.qtl.all.only.days <-  out.qtl.all[, c(1:3,grep("NV_DAYS",colnames(out.qtl.all)),grep("vern_DAYS",colnames(out.qtl.all)))]
# Now, we remove it from the main table 
out.qtl.all.only.leaves<- out.qtl.all[, -c(grep("NV_DAYS",colnames(out.qtl.all)),grep("vern_DAYS",colnames(out.qtl.all)))]

# Now, we reorganise the data using Tidyr
out.qtl.all.main.pheno.leaves <-  tidyr::gather(out.qtl.all.only.leaves, Condition, Observation, 4:length(out.qtl.all.only.leaves))
out.qtl.all.main.pheno.days <-  tidyr::gather(out.qtl.all.only.days, Condition, Observation, 4:length(out.qtl.all.only.days))

out.qtl.all.main.pheno.all.data <- tidyr::gather(out.qtl.all, Condition, Observation, 4:length(out.qtl.all))

# Now, we will create a new table with all the data including the type of observation (leaves or days)
out.qtl.all.main.pheno.leaves_temp <- out.qtl.all.main.pheno.leaves
out.qtl.all.main.pheno.leaves_temp$criteria <- rep("Leaves", length(out.qtl.all.main.pheno.leaves_temp$chr))
out.qtl.all.main.pheno.days_temp <- out.qtl.all.main.pheno.days
out.qtl.all.main.pheno.days_temp$criteria <- rep("Days_to_flower", length(out.qtl.all.main.pheno.days_temp$chr))
# We put the data in the same table using rbind
out.qtl.all.main.pheno.all.data<- rbind(out.qtl.all.main.pheno.leaves_temp,out.qtl.all.main.pheno.days_temp)
out.qtl.all.main.pheno.all.data$Condition <- gsub("_DAYS_Value","",out.qtl.all.main.pheno.all.data$Condition)
out.qtl.all.main.pheno.all.data$Condition <- gsub("_LEAVES_Value","",out.qtl.all.main.pheno.all.data$Condition)

# Now, we draw our graph
## First, we define the colors of the lines
custom_gradient <- c("#3763E8","#FF334A","#974EFF","#E83BA6","#FF6B3B")
LOD_threshold <- LOD_value_auto

##### Graph with raw data
### SET UP
value_conditions <- unique(out.qtl.all.main.pheno.all.data$Condition)
condition_info <- value_conditions[1:5]
# We use factor to order the different conditions
out.qtl.all.main.pheno.all.data$Condition <- factor(out.qtl.all.main.pheno.all.data$Condition, levels=c(value_conditions[1],value_conditions[2],value_conditions[3],value_conditions[4],value_conditions[5]))
# We reshape it to create a column for Days, and another one for Leaves
out.qtl.all.main.pheno.all.except_lemma_reshaped <- tidyr::spread(out.qtl.all.main.pheno.all.data,criteria,Observation)

### GRAPH CREATION
p <- ggplot(out.qtl.all.main.pheno.all.except_lemma_reshaped, aes(pos,Days_to_flower))
p <- p + geom_line(aes(x=pos, y=Days_to_flower,colour = chr), size=.3, alpha=.9) + geom_area(alpha=0.7, aes(x=pos, y=Days_to_flower, fill=chr),stat = 'identity', position = 'identity')
p <- p + facet_grid(Condition ~ chr,scales='free', space="free_x") + scale_y_continuous(expand = c(0,0.1))#+theme_hc(base_size = 8)
p <- p + geom_hline(yintercept=LOD_threshold, alpha=0.5, colour="#FF3333", size=0.6) + xlab("Position on chromosome (cM)") + ylab("LOD score")
p <- p + geom_line(aes(x=pos,y=Leaves, colour=chr), linetype = "1111", alpha=0.4)+ ylim(0,7) 
p <- p + scale_colour_manual(values=custom_gradient) + scale_fill_manual(values=custom_gradient)
p <- p + theme_bw()  + theme(panel.background = element_rect(fill = "#FFFFFF"),
                             strip.background = element_rect(fill = '#FFFFFF',color = "#FFFFFF", size = 0.5),
                             panel.border = element_rect(color = "#818181", fill = NA, size = 0.5),
                             panel.margin.x = unit(-0.1, "lines"),
                             legend.position="none"
)
print(p)
ggsave(paste(path_to_results,"/9A_QTL_results_full_table_raw_data.png", sep=""), p, height=7.5, width=10)

#@###--------------- 7 - TWO-PEAKS QTL ANALYSIS --------#######

two.peaks.qtl.nv.20h <- scantwo(qtl_all2, method=scaneone_method, phe=3)
png(paste(path_to_results,'/10a_Correlation_basic_graph.png', sep=""), width = 900, height = 600)
plot(two.peaks.qtl.nv.20h)
dev.off()

png(paste(path_to_results,'/10b_Correlation_two_qtl_model_fv1_lower.png', sep=""), width = 900, height = 600)
plot(two.peaks.qtl.nv.20h,lower="fv1")
dev.off()

png(paste(path_to_results,'/10c_Correlation_two_qtl_model_vf1_low_av1_up.png', sep=""), width = 900, height = 600)
plot(two.peaks.qtl.nv.20h,lower="fv1",upper="av1")
dev.off()

png(paste(path_to_results,'/10d_Correlation_two_qtl_model_lower_vf1.png', sep=""), width = 650, height = 600)
plot(two.peaks.qtl.nv.20h,lower="fv1" , upper="full", zscale=T)
dev.off()

png(paste(path_to_results,'/10e_Correlation_two_qtl_av1low_upper_av1.png', sep=""), width = 650, height = 600)
plot(two.peaks.qtl.nv.20h,lower="av1" , upper="add", zscale=T)
dev.off()

# If we want to caluculate the p-value, here is the code. Be carefull, takes hours.
if(Perform_scantwo_permutation=="YES"){
operm2 <- scantwo(qtl_all2, method="hk", n.perm=number_permutations_two,phe=3,n.cluster=number_of_clusters)
} else{
operm2 <- scantwo(qtl_all2, method="hk", n.perm=4,phe=3,n.cluster=number_of_clusters)
}

lod_value.two.peaks <- summary(operm2, alpha=alpha_permutation_two)
pvalue.data.frame <- summary(two.peaks.qtl.nv.20h,perms=operm2, alpha=0.05, pvalues=TRUE, digits = 10)

save_epistasis_table <- paste(path,"/Tables_produced/8_Results_p_value_epistasis.csv",sep="")
write.csv(pvalue.data.frame,save_epistasis_table)


#@###--------------- 8 - Interaction between loci - 20h NV --------#######

############# Now, we will identify the marker of the main peak in chromosom 1 and 3 
### The purpose is to look at the flowering time of the corresponding lines
summary.qtl.nv.20h <- scanone(qtl_all2, method=scaneone_method, phe=3)
# We select the peaks above the significance threshold identified previously
table_peaks <- summary(summary.qtl.nv.20h, threshold = LOD_value_auto)
# We identify the marker closes to the peaks maximum
Marker1 <- find.marker(qtl_all_data, chr=table_peaks$chr[1], pos=table_peaks$pos[1])
Marker2 <- find.marker(qtl_all_data, chr=table_peaks$chr[2], pos=table_peaks$pos[2])

# Now, we will use the name of these data to filter the table of phenotype
##### First, we load the full table of phenotype + genotype created earlier
all_geno_data_to_filter <- read.csv2("Tables_produced/7_qtl_reshaped_table_2_GENETIC_distances_all_markers.csv", sep="\t")
# We extract the data of the phenotype of interest as well as the marker of interst 
new_data_frame <- data.frame(ID_subset_marker = all_geno_data_to_filter$ID,
                             phenotype_marker_1 = all_geno_data_to_filter[,which(colnames(all_geno_data_to_filter)==paste(Marker1))],
                             phenotype_marker_2 = all_geno_data_to_filter[,which(colnames(all_geno_data_to_filter)==paste(Marker2))],
                             phenotype_nv20_leaves =  as.numeric(as.character(all_geno_data_to_filter$X20hr.NV_LEAVES_Value)),
                             phenotype_nv20_days =  all_geno_data_to_filter$X20hr.NV_DAYS_Value
)
# Now, we remove the first two lines that are, here, useless. 
new_data_frame <- new_data_frame[-c(1:2),]
# We use the NA data to remove uncomplete lines
new_data_frame.2 <- new_data_frame[complete.cases(new_data_frame),]
# As it is difficult to deal with H, we remove these lines
new_data_frame.3 <- new_data_frame.2[-which(new_data_frame.2$phenotype_marker_1=="HET"),]
new_data_frame.3 <- new_data_frame.3[-which(new_data_frame.3$phenotype_marker_2=="HET"),]
new_data_frame.3 <- new_data_frame.3[-which(new_data_frame.3$phenotype_marker_2=="UNK"),]
new_data_frame.3 <- new_data_frame.3[-which(new_data_frame.3$phenotype_marker_1=="UNK"),]

# Now, we will create a new column with the information of both markers
new_data_frame.3$Marker1_Marker2 <- paste(new_data_frame.3$phenotype_marker_1,new_data_frame.3$phenotype_marker_2, sep="_")

#Now, we draw the corresponding graph
### First, days to heading
p <- ggplot(new_data_frame.3, aes(x=Marker1_Marker2, y=phenotype_nv20_days))
p <- p + theme_bw()
p <- p + geom_boxplot(fill="#3F5C7A", alpha=.3,outlier.shape = NA)
p <- p +  geom_jitter(alpha=.5, width = .5, aes(fill="#3F5C7A"))
#p <- p + ylim(0, max((new_data_frame.3$phenotype_nv20_days)+20))
p <- p + ylab("Days to heading") + xlab("Genotype") + theme(legend.position="none")
p <- p + scale_y_continuous(limits = c(0, max(new_data_frame.3$phenotype_nv20_days)+20), expand = c(0, 0)) 
print(p)
ggsave(paste(path_to_results,"/11A_Flowering_time_days_correlation_two_main_peaks.png",sep="/"), height=5,width=8)

### Second, the number of leaves at flowering
p <- ggplot(new_data_frame.3, aes(x=Marker1_Marker2, y=phenotype_nv20_leaves))
p <- p + theme_bw()
p <- p + geom_boxplot(fill="#3F5C7A", alpha=.5,outlier.shape = NA)
p <- p +  geom_jitter(alpha=.5, width = .5, aes(fill="#3F5C7A"))
#p <- p + ylim(0, max((new_data_frame.3$phenotype_nv20_days)+20))
p <- p + ylab("Leaves at flowering") + xlab("Genotype") + theme(legend.position="none")
p <- p + scale_y_continuous(limits = c(0, max(new_data_frame.3$phenotype_nv20_leaves)+5), expand = c(0, 0)) 
print(p)
ggsave(paste(path_to_results,"11B_Flowering_time_leaves_correlation_two_main_peaks.png",sep="/"), height=5,width=8)

p <- ggplot(new_data_frame.3, aes(x=Marker1_Marker2, y=phenotype_nv20_leaves))
p <- p + theme_bw()
p <- p + geom_boxplot(fill="#3F5C7A", alpha=.5,outlier.shape = NA)
p <- p +  geom_jitter(alpha=.5, width = .5, aes(fill="#3F5C7A"))
#p <- p + ylim(0, max((new_data_frame.3$phenotype_nv20_days)+20))
p <- p + ylab("Leaves at flowering") + xlab("Genotype") + theme(legend.position="none")
p <- p + scale_y_continuous(limits = c(0, max(new_data_frame.3$phenotype_nv20_leaves)+5), expand = c(0, 0)) 
print(p)
ggsave(paste(path_to_results,"/11B_Flowering_time_leaves_correlation_two_main_peaks.png",sep="/"), height=5,width=8)

# Now, we perform the Tukey test to test the corresponding phenotypes
## First, the days to heading
Tukey_days <- TukeyHSD(aov(phenotype_nv20_days ~ Marker1_Marker2, data=new_data_frame.3))
save_Tukey_days <- paste(path_to_tables,"/10A_Results_Tukey_NV20h_days.csv",sep="")
write.csv(data.frame(Tukey_days$Marker1_Marker2),save_Tukey_days)
## Second, the leaves at flowering
Tukey_leaves <- TukeyHSD(aov(phenotype_nv20_leaves ~ Marker1_Marker2, data=new_data_frame.3))
save_Tukey_leaves <- paste(path_to_tables,"/10B_Results_Tukey_NV20h_leaves.csv",sep="")
write.csv(data.frame(Tukey_leaves$Marker1_Marker2),save_Tukey_leaves)

#@###-------------- 9 - Computing variance for each phenotypic conditions 
# max(out[out$chr==1 & out$pos > 50,])
# Extract data flowering 
NV_h16 <- scanone(qtl_all2, method=scaneone_method, phe=1)
NV_h20 <- scanone(qtl_all2, method=scaneone_method, phe=3)
Vern2W_h16 <- scanone(qtl_all2, method=scaneone_method, phe=5)
Vern2W_h20 <- scanone(qtl_all2, method=scaneone_method, phe=7)
Vern3W_h16 <- scanone(qtl_all2, method=scaneone_method, phe=9)


subset_valueNV_h16 <- NV_h16[which(NV_h16$lod>LOD_threshold),]
subset_valueNV_h16 <- subset_values[which(subset_values$chr=="3"),]
max(subset_valueNV_h16$lod)
## Analysis of NV20h
# Here, we know we have three peaks, 1 on chromosom 1 and two 
# Select values over LOD threshold
subset_values <- NV_h20[which(NV_h20$lod>LOD_threshold),]

# Subset for chromosom 1 (one peak) - FQTL1
subset_values_ch1 <- subset_values[which(subset_values$chr=="1"),]
subset_values_ch1 <- subset_values_ch1[grep("Bd",row.names(subset_values_ch1)),]
FQTL1_name <- row.names(subset_values_ch1)[which(subset_values_ch1$lod==max(subset_values_ch1$lod))]
FQTL1_chr <- subset_values_ch1[which(subset_values_ch1$lod==max(subset_values_ch1$lod)),"chr"]
FQTL1_position <- subset_values_ch1[which(subset_values_ch1$lod==max(subset_values_ch1$lod)),"pos"]

# Peak_2 - chromosom three - three peaks
subset_values_ch3 <- subset_values[which(subset_values$chr=="3"),]
subset_values_ch3 <- subset_values_ch3[grep("Bd",row.names(subset_values_ch3)),]
# FQTL3
subset_FQTL3 <- subset_values_ch3[which(subset_values_ch3$pos<50),]
FQTL3_name <- row.names(subset_FQTL3)[which(subset_FQTL3$lod==max(subset_FQTL3$lod))]
FQTL3_chr <- subset_FQTL3[which(subset_FQTL3$lod==max(subset_FQTL3$lod)),"chr"]
FQTL3_position <- subset_FQTL3[which(subset_FQTL3$lod==max(subset_FQTL3$lod)),"pos"]
# FQTL2
subset_FQTL2 <- subset_values_ch3[which(subset_values_ch3$pos>50),]
subset_FQTL2 <- subset_FQTL2[which(subset_FQTL2$pos<75),]
FQTL2_name <- row.names(subset_FQTL2)[which(subset_FQTL2$lod==max(subset_FQTL2$lod))]
FQTL2_chr <- subset_FQTL2[which(subset_FQTL2$lod==max(subset_FQTL2$lod)),"chr"]
FQTL2_position <- subset_FQTL2[which(subset_FQTL2$lod==max(subset_FQTL2$lod)),"pos"]
# FQTL6
subset_FQTL6 <- subset_values_ch3[which(subset_values_ch3$pos>75),]
subset_FQTL6 <- subset_FQTL6[which(subset_FQTL6$pos<110),]
FQTL6_name <- row.names(subset_FQTL6)[which(subset_FQTL6$lod==max(subset_FQTL6$lod))]
FQTL6_chr <- subset_FQTL6[which(subset_FQTL6$lod==max(subset_FQTL6$lod)),"chr"]
FQTL6_position <- subset_FQTL6[which(subset_FQTL6$lod==max(subset_FQTL6$lod)),"pos"]
# FQTL7
subset_values_3 <- NV_h20[which(NV_h20$lod>2.5),]
# Subset for chromosom 1 (one peak) - FQTL1
subset_values_ch2 <- subset_values_3[which(subset_values_3$chr=="2"),]
subset_values_ch2 <- subset_values_ch2[grep("Bd",row.names(subset_values_ch2)),]
FQTL7_name <- row.names(subset_values_ch2)[which(subset_values_ch2$lod==max(subset_values_ch2$lod))]
FQTL7_chr <- subset_values_ch2[which(subset_values_ch2$lod==max(subset_values_ch2$lod)),"chr"]
FQTL7_position <- subset_values_ch2[which(subset_values_ch2$lod==max(subset_values_ch2$lod)),"pos"]
FQTL7_name <- FQTL7_name[1]
FQTL7_chr <- FQTL7_chr[1]
FQTL7_position <- FQTL7_position[1]

## Analysis of 20h 2W VERN
# Select values over LOD threshold
subset_values2 <- Vern2W_h20[which(Vern2W_h20$lod>LOD_threshold),]
# FQTL 4 = peak at toward the end of ch3
subset_values_ch3_bis <- subset_values2[which(subset_values2$chr=="3"),]
subset_FQTL4 <- subset_values_ch3bis[grep("Bd",row.names(subset_values_ch3bis)),]
# Marker number 2
FQTL4_name <- row.names(subset_FQTL4)[which(subset_FQTL4$lod==max(subset_FQTL4$lod))]
FQTL4_chr <- subset_FQTL4[which(subset_FQTL4$lod==max(subset_FQTL4$lod)),"chr"]
FQTL4_position <- subset_FQTL4[which(subset_FQTL4$lod==max(subset_FQTL4$lod)),"pos"]

# Now, for FQTL5, we select the peak not significant at the end of Ch. 3
# First, we isolate the end of ch. 3
subset_for_fqtl5 <- Vern2W_h20[which(Vern2W_h20$lod>2),]
subset_for_fqtl5 <- subset_for_fqtl5[which(subset_for_fqtl5$chr=="3"),]
subset_for_fqtl5 <- subset_for_fqtl5[which(subset_for_fqtl5$pos>275),]
subset_for_fqtl5 <- subset_for_fqtl5[which(subset_for_fqtl5$pos<310),]
subset_for_fqtl5 <- subset_for_fqtl5[grep("Bd",row.names(subset_for_fqtl5)),]
FQTL5_name <- row.names(subset_for_fqtl5)[which(subset_for_fqtl5$lod==max(subset_for_fqtl5$lod))]
FQTL5_chr <- subset_for_fqtl5[which(subset_for_fqtl5$lod==max(subset_for_fqtl5$lod)),"chr"]
FQTL5_position <- subset_for_fqtl5[which(subset_for_fqtl5$lod==max(subset_for_fqtl5$lod)),"pos"]

# Now, let's find FQTL8
subset_for_fqtl8 <- Vern2W_h20[which(Vern2W_h20$lod>2),]
subset_for_fqtl8 <- subset_for_fqtl8[which(subset_for_fqtl8$chr=="3"),]
subset_for_fqtl8 <- subset_for_fqtl8[which(subset_for_fqtl8$pos<15),]
subset_for_fqtl8 <- subset_for_fqtl8[grep("Bd",row.names(subset_for_fqtl8)),]
subset_for_fqtl8 <- subset_for_fqtl8[-which(subset_for_fqtl8$pos==0),]

FQTL8_name <- row.names(subset_for_fqtl8)[which(subset_for_fqtl8$lod==max(subset_for_fqtl8$lod))]
FQTL8_name <- FQTL8_name[1]
FQTL8_chr <- subset_for_fqtl8[which(subset_for_fqtl8$lod==max(subset_for_fqtl8$lod)),"chr"]
FQTL8_chr <- FQTL8_chr[1]
FQTL8_position <- subset_for_fqtl8[which(subset_for_fqtl8$lod==max(subset_for_fqtl8$lod)),"pos"]
FQTL8_position <- FQTL8_position[1]

Peak_names <- c("FQTL1","FQTL2","FQTL3","FQTL4","FQTL5","FQTL6","FQTL7","FQTL8")
Peak_markers <- c(FQTL1_name,FQTL2_name,FQTL3_name,FQTL4_name,FQTL5_name,FQTL6_name,FQTL7_name,FQTL8_name)
Peak_chromosom_numbers <- c(FQTL1_chr,FQTL2_chr,FQTL3_chr,FQTL4_chr,FQTL5_chr,FQTL6_chr,FQTL7_chr,FQTL8_chr)
Peak_positions <- c(FQTL1_position,FQTL2_position,FQTL3_position,FQTL4_position,FQTL5_position,FQTL6_position,FQTL7_position,FQTL8_position)
# We will create a table with the summary of the different peaks, markers and position
data.frame.peaks <- data.frame("Peaks" = Peak_names,
                               "Marker name" = Peak_markers,
                               "Chromosom" = Peak_chromosom_numbers,
                               "Position in cM" = Peak_positions
)
save_qtl_peaks <- paste(path_to_tables,"/11_Peak_positions.csv",sep="")
write.csv(data.frame.peaks,save_qtl_peaks)

# We perform a "makeqtl" analysis to draw the QTL peaks on the genetic map
qtl_all_jitter <- jittermap(qtl_all2)
qtl_all_jitter <- calc.genoprob(qtl_all_jitter, step=1)
qtl <- makeqtl(qtl_all_jitter, chr=Peak_chromosom_numbers, pos=Peak_positions,qtl.name=Peak_names, what="prob") 
png(paste(path_to_results,'/12_Position_saved_markers.png', sep=""), width = 900, height = 600)
plot(qtl)
dev.off()

### NOW that we have the positions of the different QTLs, we perform an analysis, for each condition, of the contribution
# of the QTL peak to the phenotypic variance observed.
# First, we use jittermap to conserve only one marker per chromosomic position
qtl_all_final <- jittermap(qtl_all2)
qtl_all_final <- calc.genoprob(qtl_all_final, step=1)
#qtl_all_final <- scanone(qtl_all_final, method="hk") 

######## NV h16
pheno.column <- 1
qtl <- makeqtl(qtl_all_final, chr=FQTL1_chr, pos=FQTL1_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL1 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL2)
qtl <- makeqtl(qtl_all_final, chr=FQTL2_chr, pos=FQTL2_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL2 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL3)
qtl <- makeqtl(qtl_all_final, chr=FQTL3_chr, pos=FQTL3_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL3 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL4)
qtl <- makeqtl(qtl_all_final, chr=FQTL4_chr, pos=FQTL4_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL4 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL5)
qtl <- makeqtl(qtl_all_final, chr=FQTL5_chr, pos=FQTL5_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL5 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL6)
qtl <- makeqtl(qtl_all_final, chr=FQTL6_chr, pos=FQTL6_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL6 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL7)
qtl <- makeqtl(qtl_all_final, chr=FQTL7_chr, pos=FQTL7_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL7 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL8)
qtl <- makeqtl(qtl_all_final, chr=FQTL8_chr, pos=FQTL8_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL8 <- out.fitqtl$result.full[1,5] 
NV_h16_Variance_single_qtl_model <- c(variance_FQTL1,variance_FQTL2,variance_FQTL3,variance_FQTL4,variance_FQTL5,variance_FQTL6,variance_FQTL7,variance_FQTL8)

######## NV h20
pheno.column <- 3
qtl <- makeqtl(qtl_all_final, chr=FQTL1_chr, pos=FQTL1_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL1 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL2)
qtl <- makeqtl(qtl_all_final, chr=FQTL2_chr, pos=FQTL2_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL2 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL3)
qtl <- makeqtl(qtl_all_final, chr=FQTL3_chr, pos=FQTL3_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL3 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL4)
qtl <- makeqtl(qtl_all_final, chr=FQTL4_chr, pos=FQTL4_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL4 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL5)
qtl <- makeqtl(qtl_all_final, chr=FQTL5_chr, pos=FQTL5_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL5 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL6)
qtl <- makeqtl(qtl_all_final, chr=FQTL6_chr, pos=FQTL6_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL6 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL7)
qtl <- makeqtl(qtl_all_final, chr=FQTL7_chr, pos=FQTL7_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL7 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL8)
qtl <- makeqtl(qtl_all_final, chr=FQTL8_chr, pos=FQTL8_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL8 <- out.fitqtl$result.full[1,5] 
NV_h20_Variance_single_qtl_model <- c(variance_FQTL1,variance_FQTL2,variance_FQTL3,variance_FQTL4,variance_FQTL5,variance_FQTL6,variance_FQTL7,variance_FQTL8)

######## h16 | 2W Vern
pheno.column <- 5
qtl <- makeqtl(qtl_all_final, chr=FQTL1_chr, pos=FQTL1_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL1 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL2)
qtl <- makeqtl(qtl_all_final, chr=FQTL2_chr, pos=FQTL2_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL2 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL3)
qtl <- makeqtl(qtl_all_final, chr=FQTL3_chr, pos=FQTL3_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL3 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL4)
qtl <- makeqtl(qtl_all_final, chr=FQTL4_chr, pos=FQTL4_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL4 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL5)
qtl <- makeqtl(qtl_all_final, chr=FQTL5_chr, pos=FQTL5_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL5 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL6)
qtl <- makeqtl(qtl_all_final, chr=FQTL6_chr, pos=FQTL6_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL6 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL7)
qtl <- makeqtl(qtl_all_final, chr=FQTL7_chr, pos=FQTL7_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL7 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL8)
qtl <- makeqtl(qtl_all_final, chr=FQTL8_chr, pos=FQTL8_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
h16_2WVern_Variance_single_qtl_model <- c(variance_FQTL1,variance_FQTL2,variance_FQTL3,variance_FQTL4,variance_FQTL5,variance_FQTL6,variance_FQTL7,variance_FQTL8)

######## h20 | 2W Vern
pheno.column <- 7
qtl <- makeqtl(qtl_all_final, chr=FQTL1_chr, pos=FQTL1_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL1 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL2)
qtl <- makeqtl(qtl_all_final, chr=FQTL2_chr, pos=FQTL2_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL2 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL3)
qtl <- makeqtl(qtl_all_final, chr=FQTL3_chr, pos=FQTL3_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL3 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL4)
qtl <- makeqtl(qtl_all_final, chr=FQTL4_chr, pos=FQTL4_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL4 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL5)
qtl <- makeqtl(qtl_all_final, chr=FQTL5_chr, pos=FQTL5_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL5 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL6)
qtl <- makeqtl(qtl_all_final, chr=FQTL6_chr, pos=FQTL6_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL6 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL7)
qtl <- makeqtl(qtl_all_final, chr=FQTL7_chr, pos=FQTL7_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL7 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL8)
qtl <- makeqtl(qtl_all_final, chr=FQTL8_chr, pos=FQTL8_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
h20_2WVern_Variance_single_qtl_model <- c(variance_FQTL1,variance_FQTL2,variance_FQTL3,variance_FQTL4,variance_FQTL5,variance_FQTL6,variance_FQTL7,variance_FQTL8)

######## h16 | 3W Vern
pheno.column <- 9
qtl <- makeqtl(qtl_all_final, chr=FQTL1_chr, pos=FQTL1_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL1 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL2)
qtl <- makeqtl(qtl_all_final, chr=FQTL2_chr, pos=FQTL2_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL2 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL3)
qtl <- makeqtl(qtl_all_final, chr=FQTL3_chr, pos=FQTL3_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL3 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL4)
qtl <- makeqtl(qtl_all_final, chr=FQTL4_chr, pos=FQTL4_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL4 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL5)
qtl <- makeqtl(qtl_all_final, chr=FQTL5_chr, pos=FQTL5_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL5 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL6)
qtl <- makeqtl(qtl_all_final, chr=FQTL6_chr, pos=FQTL6_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL6 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL7)
qtl <- makeqtl(qtl_all_final, chr=FQTL7_chr, pos=FQTL7_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
variance_FQTL7 <- out.fitqtl$result.full[1,5] 
# Model = 1 QTL (FQTL8)
qtl <- makeqtl(qtl_all_final, chr=FQTL8_chr, pos=FQTL8_position, what="prob") 
out.fitqtl <- fitqtl(qtl_all_final, qtl=qtl, method="hk", pheno.col=pheno.column) 
h16_3WVern_Variance_single_qtl_model <- c(variance_FQTL1,variance_FQTL2,variance_FQTL3,variance_FQTL4,variance_FQTL5,variance_FQTL6,variance_FQTL7,variance_FQTL8)


data.frame.peaks <- data.frame("Peaks" = Peak_names,
                               "Marker name" = Peak_markers,
                               "Chromosom" = Peak_chromosom_numbers,
                               "Position in cM" = Peak_positions,
                               "Contribution NV h16" = NV_h16_Variance_single_qtl_model,
                               "Contribution NV h20" = NV_h20_Variance_single_qtl_model,
                               "Contribution 2W h16" = h16_2WVern_Variance_single_qtl_model,
                               "Contribution 2W h20" = h20_2WVern_Variance_single_qtl_model,
                               "Contribution 3W h16" = h16_3WVern_Variance_single_qtl_model
)
save_qtl_peaks <- paste(path_to_tables,"/11bis_Peak_positions_with_contributions.csv",sep="")
write.csv(data.frame.peaks,save_qtl_peaks)




#@###--------------- 10 - EXPORT THE PARAMETERS OF THE ANALYSIS  --------#######

### Set an output text with the parameters used in this analysis
sink('analysis-output.txt')
cat("PARAMETERS OF THIS ANALYSIS \n")
cat("\nMaximal value set for the number of days to flowering (inferred data) =",value_max_FT_days, "\n")
cat("\nMaximal value set for the number of leaves at flowering (inferred data) =",value_max_FT_leaves,"\n")
cat("\nThe proportion of present data for a specific marker under which the marker was removed = ",marker_missing_data_threshold,"\n")
cat("\nThe proportion of missing data for a specific line above which the marker was removed = ",individual_missing_data_threshold,"\n")
cat("\nMinimal and Maximal accepted proportions of markers from a given genotype in a specific line under and above which, respectively, the individual was discarded = ",down_threshold_per_genotype," and ",up_threshold_per_genotype,"\n")
cat("\nThreshold of identity between lines above which they were considered as identical and one was removed = ", threshold_identic_lines,"\n")
cat("\nLOD treshold set for the identification of QTL peaks=",LOD_threshold,"\n")
cat("\nWere the missing data inferred using the fill.geno() function :",Fill_missing,"\n")
cat("\n Scaneone computation parameters \n")
cat("\nThe method used for the scanone function = ",scaneone_method,"\n")
cat("\nThe number of permutation used to compute the LOD threshold of the scaneone function= ",number_permutations,"\n")
cat("\nAlpha used to compute the LOD threshold of the scanone method = ",alpha_permutation,"\n")
cat("\nLOD threshold computed using the permutation method described above (scanone) = ",LOD_value_auto,"\n")
cat("\n Scanetwo computation parameters \n")
cat("\nThe method used for the scanone function = ",scaneone_method,"\n")
cat("\nDid permutations where performed for the scanetwho method?",Perform_scantwo_permutation,"\n")
cat("\nThe number of permutation used to compute the LOD threshold of the scantwo function= ",number_permutations_two,"\n")
cat("\nAlpha used to compute the LOD threshold of the scantwo method = ",alpha_permutation_two,"\n")
cat("\nLOD threshold computed using the permutation method described above (scanone) - FULL = ",lod_value.two.peaks$full,"\n")
cat("\nLOD threshold computed using the permutation method described above (scanone) - fv1 = ",lod_value.two.peaks$fv1,"\n")
cat("\nTechnical information \n")
cat("\nThe permutation were performed using ",number_of_clusters," clusters \n")
sink()